Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/Ultimaker/Cura.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJaime van Kessel <nallath@gmail.com>2022-02-11 15:40:21 +0300
committerJaime van Kessel <nallath@gmail.com>2022-02-11 15:40:21 +0300
commitcfb0604067042a33d3c6f71a604ca416be4d5f22 (patch)
tree99a03481f5936cba4bc8a7629d7678e9a0e7cfd8
parentd50a51396edbcd4f1dc5f9e04e25c09f9eedc128 (diff)
Clarify some documentation in the PerObjectSettingVisibilityHandler
We often used shorthands for stack / instance / definition, but this made it harder for people that are very familiar with the code to understand what is going on. Contributes to #11455
-rw-r--r--plugins/PerObjectSettingsTool/PerObjectSettingVisibilityHandler.py13
1 files changed, 7 insertions, 6 deletions
diff --git a/plugins/PerObjectSettingsTool/PerObjectSettingVisibilityHandler.py b/plugins/PerObjectSettingsTool/PerObjectSettingVisibilityHandler.py
index 401396f2b8..9fca618322 100644
--- a/plugins/PerObjectSettingsTool/PerObjectSettingVisibilityHandler.py
+++ b/plugins/PerObjectSettingsTool/PerObjectSettingVisibilityHandler.py
@@ -62,7 +62,7 @@ class PerObjectSettingVisibilityHandler(UM.Settings.Models.SettingVisibilityHand
all_instances = settings.findInstances()
visibility_changed = False # Flag to check if at the end the signal needs to be emitted
# Remove all instances that are not in visibility list
for instance in all_instances:
# exceptionally skip setting
if instance.definition.key in self._skip_reset_setting_set:
@@ -71,29 +71,30 @@ class PerObjectSettingVisibilityHandler(UM.Settings.Models.SettingVisibilityHand
settings.removeInstance(instance.definition.key)
visibility_changed = True
# Add all instances that are not added, but are in visibility list
for item in visible:
if settings.getInstance(item) is not None: # Setting was added already.
continue
definition = self._stack.getSettingDefinition(item)
if not definition:
- Logger.log("w", f"Unable to add instance ({item}) to per-object visibility because we couldn't find the matching definition.")
+ Logger.log("w", f"Unable to add SettingInstance ({item}) to the per-object visibility because we couldn't find the matching SettingDefinition.")
continue
new_instance = SettingInstance(definition, settings)
stack_nr = -1
stack = None
- # Check from what stack we should copy the raw property of the setting from.
+ # Check from what ContainerStack we should copy the raw property of the setting from.
if self._stack.getProperty("machine_extruder_count", "value") > 1:
if definition.limit_to_extruder != "-1":
- # A limit to extruder function was set and it's a multi extrusion machine. Check what stack we do need to use.
+ # A limit_to_extruder function was set and it's a multi extrusion machine. Check what stack we
+ # do need to use.
stack_nr = str(int(round(float(self._stack.getProperty(item, "limit_to_extruder")))))
# Check if the found stack_number is in the extruder list of extruders.
if stack_nr not in ExtruderManager.getInstance().extruderIds and self._stack.getProperty("extruder_nr", "value") is not None:
stack_nr = -1
- # Use the found stack number to get the right stack to copy the value from.
+ # Use the found stack_number to get the right ContainerStack to copy the value from.
if stack_nr in ExtruderManager.getInstance().extruderIds:
stack = ContainerRegistry.getInstance().findContainerStacks(id = ExtruderManager.getInstance().extruderIds[stack_nr])[0]
else:
@@ -62,7 +62,7 @@ class PerObjectSettingVisibilityHandler(UM.Settings.Models.SettingVisibilityHand
all_instances = settings.findInstances()
visibility_changed = False # Flag to check if at the end the signal needs to be emitted
- # Remove all instances that are not in visibility list
+ # Remove all SettingInstances that are not in visibility list
for instance in all_instances:
# exceptionally skip setting
@@ -71,29 +71,30 @@ class PerObjectSettingVisibilityHandler(UM.Settings.Models.SettingVisibilityHand
settings.removeInstance(instance.definition.key)
visibility_changed = True
- # Add all instances that are not added, but are in visibility list
+ # Add all SettingInstances that are not added, but are in visibility list
for item in visible:
if settings.getInstance(item) is not None: # Setting was added already.